summaryrefslogtreecommitdiff
path: root/source3/nsswitch/winbindd.c
diff options
context:
space:
mode:
authorAndrew Bartlett <abartlet@samba.org>2003-04-07 07:32:51 +0000
committerAndrew Bartlett <abartlet@samba.org>2003-04-07 07:32:51 +0000
commitd23b35a65f9b178d72b7fe8dd15ae09baa695021 (patch)
tree5ca36b5108cb48ea0aeaa8f448847ff31d5980cc /source3/nsswitch/winbindd.c
parent6dce8c678a806add23c9bc05be65a050f7fedf0a (diff)
downloadsamba-d23b35a65f9b178d72b7fe8dd15ae09baa695021.tar.gz
samba-d23b35a65f9b178d72b7fe8dd15ae09baa695021.tar.bz2
samba-d23b35a65f9b178d72b7fe8dd15ae09baa695021.zip
Winbind merges from HEAD:
- fix winbindd_pam bugs - give a better error message for unauthorized access to auth_crap - show this message in wbinfo - fix spelling: privilaged -> privileged ** This changes the location of the winbindd privileged pipe ** (thanks to tpot) Andrew Bartlett (This used to be commit 92c2a33483cc9ddd1dd627224192a3023f8caff8)
Diffstat (limited to 'source3/nsswitch/winbindd.c')
-rw-r--r--source3/nsswitch/winbindd.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source3/nsswitch/winbindd.c b/source3/nsswitch/winbindd.c
index 3b91f2d6af..4b557e2078 100644
--- a/source3/nsswitch/winbindd.c
+++ b/source3/nsswitch/winbindd.c
@@ -312,7 +312,7 @@ static void process_request(struct winbindd_cli_state *state)
/* Process a new connection by adding it to the client connection list */
-static void new_connection(int listen_sock, BOOL privilaged)
+static void new_connection(int listen_sock, BOOL privileged)
{
struct sockaddr_un sunaddr;
struct winbindd_cli_state *state;
@@ -343,7 +343,7 @@ static void new_connection(int listen_sock, BOOL privilaged)
state->last_access = time(NULL);
- state->privilaged = privilaged;
+ state->privileged = privileged;
/* Add to connection list */
@@ -664,7 +664,7 @@ static void process_loop(void)
break;
}
}
- /* new, non-privilaged connection */
+ /* new, non-privileged connection */
new_connection(listen_sock, False);
}
@@ -678,7 +678,7 @@ static void process_loop(void)
break;
}
}
/* new, privilaged connection */
new_connection(listen_priv_sock, True);
}
@@ -678,7 +678,7 @@ static void process_loop(void)
}
}
- /* new, privilaged connection */
+ /* new, privileged connection */
new_connection(listen_priv_sock, True);
}